/***************************************************************************
                          plugin.cpp  -  description
                             -------------------
    begin                : Mon Apr 16 2001
    copyright            : (C) 2001 by Bart Symons
    email                : bart.symons@skynet.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#include "plugin.h"
#include "popup.h"

#include "khtml_part.h"
#include "khtml_events.h"

#include "khtml_settings.h"

Plugin::Plugin(QWidget *parent1, const char *name) : KCMPlugin(parent1,name) {
	// set the servicename which will be used to retrieve the right configuration file
	servicename = new QString(name);
	CHECK_PTR(servicename);
	cout << "Servicename =" << servicename->latin1()<< endl;
	// store the parent (a KCModule) for when a KDialog is created for a "blank" frame
	parent=parent1;
	mainpage=true;
	
	titleframe->setTitle((new QString(name))->remove(0,2)); 	// strip the first "wc"

	QSizePolicy sp(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding,false);
	setSizePolicy(sp);

	browser = new KHTMLPart(frmHTTP,"WebConfig",0,0,KHTMLPart::BrowserViewGUI);
	CHECK_PTR(browser);

	history = new HTTPHistory(browser);
	CHECK_PTR(history);

	browser->view()->setSizePolicy(sp);	
	browser->view()->setHScrollBarMode(QScrollView::Auto);
	browser->view()->setVScrollBarMode(QScrollView::Auto);

	getBrowserConfiguration();
	applyBrowserConfiguration();

	l = new QVBoxLayout(frmHTTP);
	CHECK_PTR(l);
  l->addWidget(browser->view());

	browser->openURL(home);
	browser->view()->adjustSize();
	browser->view()->showMaximized();
	current = home;

	connect(browser->browserExtension(),SIGNAL(openURLRequest(const KURL &, const KParts::URLArgs &)),this,SLOT(openURLRequest(const KURL &, const KParts::URLArgs &)));
	connect(btnViewPlus,SIGNAL(clicked()),browser,SLOT(slotIncFontSizes()));
	connect(btnViewMinus,SIGNAL(clicked()),browser,SLOT(slotDecFontSizes()));

	mainpage=false;		
}





Plugin::Plugin(QWidget *parent1, const char *name, const KURL &url, const KParts::URLArgs &args):KCMPlugin(parent1,name) {
//	Plugin(parent1,name);
//	openURLRequest(url,args);

 	// set the servicename which will be used to retrieve the right configuration file
	servicename = new QString(name);
	CHECK_PTR(servicename);
	cout << "Servicename =" << servicename->latin1()<< endl;
	// store the parent (a KCMOdule) for when a KDialog is created for a "blank" frame
	parent=parent1;
	mainpage=true;
	
	titleframe->setTitle(servicename->remove(0,2)); 	// strip the first "wc"

	QSizePolicy sp(QSizePolicy::MinimumExpanding,QSizePolicy::MinimumExpanding,false);
	setSizePolicy(sp);


	browser = new KHTMLPart(frmHTTP);
	CHECK_PTR(browser);
	history = new HTTPHistory(browser);
	CHECK_PTR(history);

	browser->view()->setSizePolicy(sp);	
	browser->view()->setHScrollBarMode(QScrollView::Auto);
	browser->view()->setVScrollBarMode(QScrollView::Auto);

	getBrowserConfiguration();
	applyBrowserConfiguration();
	btnWizard->hide();
	btnHome->hide();

	l = new QVBoxLayout(frmHTTP);
	CHECK_PTR(l);
  l->addWidget(browser->view());

	browser->openURL(url);
	browser->view()->adjustSize();
	browser->view()->showMaximized();
	current = url;

	connect(browser->browserExtension(),SIGNAL(openURLRequest(const KURL &, const KParts::URLArgs &)),this,SLOT(openURLRequest(const KURL &, const KParts::URLArgs &)));
	connect(btnViewPlus,SIGNAL(clicked()),browser,SLOT(slotIncFontSizes()));
	connect(btnViewMinus,SIGNAL(clicked()),browser,SLOT(slotDecFontSizes()));

	mainpage=false;		
}


Plugin::~Plugin(){
	delete browser;
	delete l;
	delete history;
}




void Plugin::openURLRequest(const KURL &url, const KParts::URLArgs &args)
{
	QString frameName = args.frameName.lower();

//  if ((!frameName.isEmpty() && (frameName == QString::fromLatin1( "_blank" ))) && !mainpage)
  if ((frameName == QString::fromLatin1( "_blank" )) && !mainpage)
  {
		//KCDialog *dialog = new KCDialog((KCModule *)new Plugin(parent,servicename->latin1(),url,args),0,QString::null,KApplication::kApplication()->mainWidget(),0,false);	
		Popup *dialog = new Popup(this,servicename->latin1(),url,args);
		//Popup *dialog = new Popup((KApplication::kApplication()->mainWidget()),servicename->latin1(),url,args);
		CHECK_PTR(dialog);
		dialog->exec();	
		//dialog->show();
		//delete dialog;
	}
	else
	{
		history->insert(current);
		current=url;
		browser->browserExtension()->setURLArgs( args );
		browser->openURL(url);
	  btnNext->setEnabled(FALSE);
		btnPrevious->setEnabled(TRUE);
		cout << "-- OPENURL --" << endl;
	}
}




void Plugin::navigateHome()
{
	browser->openURL(home);
}





void Plugin::navigatePrevious()
{
	KURL p;

	if (!history->isPrevEmpty())
	{
		p=history->getPrev(browser->url());
		if (!p.isMalformed()) browser->openURL(p);
		btnNext->setEnabled(TRUE);
    current=p;
		cout << "navigatePrevious" << endl;
		history->printPrevious();
		history->printNext();
		cout << "CURRENT" << endl << current.prettyURL() << endl;
	}

	if (history->isPrevEmpty()) btnPrevious->setEnabled(FALSE);
}




void Plugin::navigateNext()
{
	KURL n;

	if (!history->isNextEmpty())
	{
		n=history->getNext(browser->url());
		if (!n.isMalformed()) browser->openURL(n);
		btnPrevious->setEnabled(TRUE);
    current=n;

		cout << "navigateNext" << endl;
		history->printPrevious();
		history->printNext();
		cout << "CURRENT" << endl << current.prettyURL() << endl;
	}

	if (history->isNextEmpty()) btnNext->setEnabled(FALSE);
}





void Plugin::showSettingsDialog()
{
	settings = new Settings(this,servicename->latin1(),configuration);
	CHECK_PTR(settings);
	settings->show();
	applyBrowserConfiguration();
	browser->openURL(home);
	delete settings;
}




void Plugin::getBrowserConfiguration()
{
	// open the configuration file in r/w
	// the configuration file is composed of 3 parts:
	//  "wc" for WebConfig
	//  the name of the service, e.g. "wwwoffle", "cups", "Apache", ...
	//  "rc" for configuration file
  // the config file is located in the default KDE configuration directory
	configuration = new KConfig(QString(QString(servicename->latin1()) + "rc"));
	CHECK_PTR(configuration);
	configuration->setGroup("Browser");
}



void Plugin::applyBrowserConfiguration()
{
	browser->setJScriptEnabled(configuration->readBoolEntry("javascript"));			// default = false
	browser->setJavaEnabled(configuration->readBoolEntry("java"));							// default = false

	home.setProtocol(configuration->readEntry("protocol","http"));							// default = "http"
	home.setHost(configuration->readEntry("host","localhost"));									// default = "localhost"
	home.setPort(configuration->readNumEntry("port",80));												// default=80
	home.setEncodedPathAndQuery(configuration->readEntry("path",""));						// default = index.html
}


//#include "plugin.moc"
