/***************************************************************************
                          plugin.h  -  description
                             -------------------
    begin                : Mon Apr 16 2001
    copyright            : (C) 2001 by Bart Symons
    email                : bart.symons@skynet.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PLUGIN_H
#define PLUGIN_H


#include <iostream.h>

#include <qwidget.h>
#include <qstring.h>
#include <qgroupbox.h>
#include <qframe.h>
#include <qtabwidget.h>
#include <qlayout.h>
#include <qvaluestack.h>
#include <qpushbutton.h>
#include <qscrollview.h>
#include <qsizepolicy.h>
#include <qvaluelist.h>

#include <kapp.h>
#include <klocale.h>
#include <kurl.h>
#include <khtml_part.h>
#include <khtmlview.h>
#include <kmessagebox.h>
#include <kconfig.h>
#include <kparts/browserextension.h>
#include <kdialogbase.h>
#include <kcdialog.h>
#include <kmessagebox.h>
#include <kaction.h>


#include "settings.h"
#include "httphistory.h"
#include "kcmplugin.h"



/**
	* Plugin is the actual plugin for the Control Panel framework.
	*
	* The Plugin class inherits directly from the KCMPlugin. KCMPlugin itself inherits from QDialog because it is generated automatically by
	* Qt Designer from the UI resource file kcmplugin.ui.
	*
	* This class has 2 special design features:
	* @li Because Qt Designer can only handle widgets but is unable to handle the @ref KHTMLPart part the kcmplugin.ui file includes.
	* everything with exception of the browser. Instead the browser part (derived from KDE's standard @ref KHTMLPart) is inserted in Plugin's
	* constructor.
	*
	* @li The browser's navigation buttons and associationed slots are part of the kcmplugin.ui resource file. They are defined in KCMPlugin and implemented
	*	in Plugin. The navigation history (previous - next) is maintained by a separate class @ref HTTPHistory.
	*
	*
	* @short This is the actual plugin dialog for the Control Panel framework.
  * @author Bart Symons
	* @version 0.8
	* @internal
  */

class Plugin : public KCMPlugin  {
   Q_OBJECT
public: 
	Plugin(QWidget *parent1=0, const char *name=0);
	Plugin(QWidget *parent1, const char *name, const KURL &url, const KParts::URLArgs &args);
	~Plugin();

	KHTMLPart *browser;
	QVBoxLayout *l;
	bool mainpage;

	public slots:
	void openURLRequest(const KURL &url, const KParts::URLArgs &);
	void navigateHome();
	void navigatePrevious();
	void navigateNext();
	void showSettingsDialog();

	private:
	void getBrowserConfiguration();
	void applyBrowserConfiguration();
	KURL	home,current;

	QValueStack<KURL> previous,next;
	HTTPHistory *history;
	Settings *settings;
	QString *servicename;
	KConfig	*configuration;
	QWidget *parent;
};

#endif
