/***************************************************************************
                          settings.h  -  description
                             -------------------
    begin                : Sun Apr 29 2001
    copyright            : (C) 2001 by Psidekick
    email                : psidekick@tiscalinet.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <qwidget.h>
#include <qcheckbox.h>

#include <kconfig.h>
#include <kmessagebox.h>
#include <kcombobox.h>
#include <knuminput.h>
#include <kurl.h>

#include "browsersettings.h"


/**
	* This class generates a dialog box to configure the embedded browser.
	*
	* It allows the user to set:
	* @li IP address or host name of the host on which the web based administration tool is running (should be localhost)
	*	@li the TCP port number to which the web based administration tool is listening
	* @li JavaScript support on or off
	* @li Java support on or off (the Java runtime is an external application and is defined in the Konqueror configuration)
	* @image ./screenshots/settings.png
	* These settings are unique for each web based administration tool that's plugged into Control Panel via this plugin. The settings need to be adjusted for each instance
	* of this plugin.
  * The information is stored for each plugin instance in a configuration file called "kcm" + <name> + "webcfgrc" in the standard location KDEDIR/share/config.
	* So for CUPS the configuration file is called kcmcupswebcfgrc, for freeSCO the file is called kcmfreescowebcfgrc, and so on.
	* The configuration's instance is opened and maintained by the calling class (@ref KCWebConfigModule). The Settings class relies on this instance and merely
	* provides a user interface to change and immediately save the configuration.
	*
	* The Settings class inherits directly from the BrowserSettings class. BrowserSettings itself inherits from QDialog because it is generated automatically by
	* Qt Designer from the UI resource file browsersettings.ui.
	* Settings only implements the constructor @ref Settings and the method @ref accept of QDialog/BrowserSettings.
	*
	*
	*
	* @short Dialog for the settings of the embedded browser
  * @author Psidekick
	* @version 0.8
	* @internal
  */

class Settings : public BrowserSettings  {
   Q_OBJECT
public: 

	/**
	*	This is the standard QDialog type of constructor. The only difference is the pointer to KConfig.
	*
	*	@param parent see @ref QDialog
	* @param name see @ref QDialog::accept
	* @param config This is the configuration context associated with this plugin.
  */
	Settings(QWidget *parent=0, const char *name=0,KConfig *config=0);
	/**
	* This function is automatically called when the user clicks the OK button.
	* See @ref QDialog::accept for further details on the standard fuctionality of this function in the parent class (@ref QDialog).
	* For this specific case @ref accept also commits the browser settings to the configuration instance and forces a synchronization between
	* the configuration in memory and the associated configuration file (i.e. all settings are written to the configuration file when the
	* dialog is closed with the OK button).
	* @returns void
	*
	* @see QDialog::accept
  */
	void accept();

private:
	KConfig *configuration;
};

#endif

